@@ -10,11 +10,8 @@ TODO: Python version check should go here...
 @author: Piotr Ozimek
 """
 
-from .cuda_objects import CudaRetina
 from .retina import Retina
-import retinavision.cortex
 import retinavision.utils
-from os.path import dirname, join
 
 datadir = join(dirname(dirname(__file__)), "data")
 
